@@ -30,7 +30,7 @@ public:
     void addItem(const QIcon &icon, const QString &text);
     void addItems(const QStringList &texts);
 
-    Q_REQUIRED_RESULT int currentIndex() const;
+    [[nodiscard]] int currentIndex() const;
 
 Q_SIGNALS:
     void rightPressed();
@@ -48,7 +48,7 @@ protected:
 private:
     void slotActionTriggered();
     QMenu *mMenu = nullptr;
-    QVector<QPair<QString, QIcon>> mList;
+    QList<QPair<QString, QIcon>> mList;
     int mCurrentIndex = -1;
 };
 
@@ -123,4 +123,3 @@ private:
     bool mModified;
 };
 }
-
