@@ -34,13 +34,13 @@ TemplateManagementDialog::TemplateManagementDialog(QWidget *parent, const QStrin
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &TemplateManagementDialog::reject);
-    setObjectName(QStringLiteral("template_management_dialog"));
+    setObjectName(QLatin1StringView("template_management_dialog"));
     connect(buttonBox->button(QDialogButtonBox::Help), &QPushButton::clicked, this, &TemplateManagementDialog::slotHelp);
     auto widget = new QWidget(this);
     mainLayout->addWidget(widget);
     mainLayout->addWidget(buttonBox);
 
-    widget->setObjectName(QStringLiteral("template_management_dialog_base"));
+    widget->setObjectName(QLatin1StringView("template_management_dialog_base"));
     m_base.setupUi(widget);
 
     m_base.m_listBox->addItems(m_templates);
