@@ -202,7 +202,7 @@ VisualFreeBusyWidget::VisualFreeBusyWidget(CalendarSupport::FreeBusyItemModel *m
     mLeftView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     mLeftView->setContextMenuPolicy(Qt::CustomContextMenu);
     mGanttGraphicsView = new KGantt::GraphicsView(this);
-    mGanttGraphicsView->setObjectName(QStringLiteral("mGanttGraphicsView"));
+    mGanttGraphicsView->setObjectName(QLatin1StringView("mGanttGraphicsView"));
     mGanttGraphicsView->setToolTip(i18nc("@info:tooltip", "Shows the Free/Busy status of all attendees"));
     mGanttGraphicsView->setWhatsThis(i18nc("@info:whatsthis",
                                            "Shows the Free/Busy status of all attendees. "
